@@ -2,7 +2,7 @@
 #' 
 #' Plot single layer imagery in grey-scale. Can be used with a SpatRaster.
 #' 
-#' @param img raster
+#' @param img SpatRaster
 #' @param layer Character or numeric. Layername or number. Can be more than one layer, in which case each layer is plotted in a subplot.
 #' @param maxpixels Integer. Maximal number of pixels to sample.
 #' @param ext Extent object to crop the image
@@ -96,7 +96,6 @@ ggR <- function(img, layer = 1, maxpixels = 500000,  alpha = 1, hue = 1, sat = 0
 
   img <- .toTerra(img)
 
-  layer <- unlist(.numBand(img, layer))
   layer <- unlist(.numBand(img, layer))
 
   multLayers <- if (length(layer)>1) TRUE else FALSE
@@ -109,31 +108,24 @@ ggR <- function(img, layer = 1, maxpixels = 500000,  alpha = 1, hue = 1, sat = 0
             call. = FALSE)
     geom_raster <- TRUE
   }
-  if(multLayers & !geom_raster & ggObj) {
-    warning("You asked for multiple layers but geom_raster is FALSE.",
-            "\ngeom_raster will be reset to TRUE",
-            "\nHint: in case you're looking for a grayscale and facetted plot, use:",
-            "\nggR(img, ..., geom_raster=TRUE)+scale_fill_gradientn(colors = grey.colors(100))",
-            call. = FALSE)
-    geom_raster <- TRUE
-  }
   annotation <- !geom_raster
 
   ex <- ext(img)
 
-  xfort <- spatSample(img[[layer]], maxpixels, ext = ex, method = "regular", as.raster = TRUE)
+  xfort <- spatSample(img[[layer]], maxpixels, ext = ex, method = "regular", as.raster = TRUE, na.rm = TRUE)
   ex <- as.vector(ext(xfort))
 
   dimImg <- dim(xfort)
 
   df <- lapply(names(xfort), function(layer) {
-    df    <- data.frame(extract(xfort, seq_along(values(xfort)), xy = TRUE),
+    df <- data.frame(extract(xfort[[layer]], seq_along(values(xfort[[layer]])), xy = TRUE),
                         layerName = factor(layer, levels = names(xfort)))
     colnames(df) <- c("x", "y", "value", "layerName")
     df
   })
   df <- do.call(rbind, df)
 
+
   if(forceCat & !is.factor(df$value)) df$value <- as.factor(df$value)
 
   if(is.character(df$value)) df$value <- factor(df$value)
