@@ -10,7 +10,7 @@
 #' }
 #' @param iterate Integer. Set maximum iteration per pixel. Processing time could increase the more iterations are made possible. Default is 400.
 #' @param tolerance Numeric. Tolerance limit representing a nearly zero minimal number. Default is 1e-8. 
-#' @param n_models Logical. Only applies if \code{em} contains column \code{class}. Defines how many endmember combinations should be picked. Maximum is the minimum number of endmembers of a class. Defaults to 5.
+#' @param n_models Logical. Only applies if \code{em} contains column \code{class}. Defines how many endmember combinations should be picked. Maximum is the minimum number of endmembers of a class. Defaults to the amount of rows of em.
 #' @param sum_to_one Logical. Defines whether a sum-to-one constraint should be applied so that probabilities of endmember classes sum to one (a constraint not covered by NNLS) to be interpretable as fractions. Defaults to \code{TRUE}. To get actual NNLS results, change to \code{FALSE}.
 #' @param verbose Logical. Prints progress messages during execution.
 #' @param ... further arguments passed to \link[terra]{writeRaster}.
@@ -72,7 +72,7 @@
 #' @importFrom terra which.min rast selectRange nlyr
 #' @export
 #' 
-mesma <- function(img, em, method = "NNLS", iterate = 400, tolerance = 0.00000001, n_models = 5, sum_to_one = TRUE, ..., verbose){
+mesma <- function(img, em, method = "NNLS", iterate = 400, tolerance = 0.00000001, n_models = NULL, sum_to_one = TRUE, ..., verbose){
   img <- .toTerra(img)
   ## messages
   if(!missing("verbose")) .initVerbose(verbose)
@@ -89,6 +89,12 @@ mesma <- function(img, em, method = "NNLS", iterate = 400, tolerance = 0.0000000
   if(anyNA(em)){
     stop("'em' is not allowed to contain NA values. Spectra must be consistent.")
   }
+
+  # Check for n_models type
+  if(!is.null(n_models) && !is.numeric(n_models)){
+    stop("'n_models' needs to be an 'numeric' object.")
+  }
+
   
   method <- toupper(method) 
   meth_avail <- c("NNLS") #available methods
@@ -115,6 +121,11 @@ mesma <- function(img, em, method = "NNLS", iterate = 400, tolerance = 0.0000000
     classes <- unique(em$class)
     # check n_models
     n_em_cl <- min(sapply(classes, function(x) nrow(em[em$class == x,]), USE.NAMES = F))
+
+    if(is.null(n_models)){
+      n_models <- n_em_cl
+    }
+
     if(n_em_cl < n_models){
       warning(paste0("'n_models' cannot be larger than the minimum number of provided endmembers per class. Setting 'n_models' to ", n_em_cl, "."))
       n_models <- n_em_cl
