@@ -2,7 +2,7 @@ context("save and read RSTBX objects")
 library(terra)
 
 ## Create RSTBX object
-train <- readRDS(system.file("external/trainingPoints.rds", package="RStoolbox"))
+train <- readRDS(system.file("external/trainingPoints_rlogo.rds", package="RStoolbox"))
 sc <- superClass(rlogo, train, tuneLength = 1, resp="class")
 
 ## Save and re-import
